/****************************************************************/
/*              Ban a domain or IP address in Weasel            */
/*                                                              */
/*      Author:       Peter Moylan (peter@ee.newcastle.edu.au)  */
/*      Started:      10 April 2012                             */
/*      Last revised: 10 April 2012                             */
/*                                                              */
/*  Usage:                                                      */
/*         ban arg                                              */
/*    or                                                        */
/*         ban arg I      (if using Weasel.INI (default)        */
/*    or                                                        */
/*         ban arg T      (if using Weasel.TNI)                 */
/*                                                              */
/*     The acceptable forms of "arg" are described in the       */
/*     "Editing a list of host names" section of the Weasel     */
/*     manual.  Note that this script does only minimal         */
/*     legality checking on the argument.                       */
/*                                                              */
/*  Installation:                                               */
/*     Put this file in the directory containing WEASEL.INI     */
/*     You must also have RXU.DLL in your LIBPATH.  RXU, a Rexx */
/*     library written by Dave Boll, is available from Hobbes   */
/*     with the name rxu1a.zip.                                 */
/*                                                              */
/****************************************************************/

CALL RxFuncAdd SysLoadFuncs, rexxutil, sysloadfuncs
CALL SysLoadFuncs
CALL rxfuncadd 'rxuinit','rxu','rxuinit'
CALL rxuinit

PARSE ARG arg tni
IF (arg = '') THEN CALL SayUsage
IF (tni = '') THEN tni = 0
ELSE IF (tni = 't') | (tni = 'T') THEN tni = 1
ELSE IF (tni = 'i') | (tni = 'I') THEN tni = 0
ELSE CALL SayUsage

/* Switch our working directory to the program directory */

PARSE SOURCE rubbish rubbish SrcDir
j = LASTPOS('\', SrcDir)
IF j > 0 THEN SrcDir = LEFT(SrcDir, j-1)
WrkDir = DIRECTORY()
CALL DIRECTORY SrcDir

/* Add the new banned domain or IP address (or range) */

arg = IsLegal(arg)
CALL AddBannedEntry arg tni

/* Tell Weasel that a change has occurred, then exit. */

SemName = "\SEM32\WEASEL\UPDATED"
IF RxOpenEventSem(hev, SemName) \= 0 THEN
    rc = RxCreateEventSem( hev ,'Shared', SemName, 'Reset')
CALL RxPostEventSem hev
CALL RxResetEventSem hev
CALL RxCloseEventSem hev
CALL RxuTerm

CALL DIRECTORY WrkDir
EXIT 0

/****************************************************************/
/*                    A USEFUL HELP MESSAGE                     */
/*               We will exit if this is called                 */
/****************************************************************/

SayUsage: PROCEDURE

    SAY "Usage: ban arg    or    ban arg I    or   ban arg T"
    SAY "where arg is a domain name or numeric address"
    SAY "(some ranges and wildcards allowed, see Weasel manual)"
    EXIT 0

/****************************************************************/
/*                SANITY CHECK ON THE NEW ENTRY                 */
/*                 For now there is no checking                 */
/****************************************************************/

IsLegal: PROCEDURE

    PARSE ARG newstring
    RETURN newstring

/****************************************************************/
/*                     ADDING A NEW ENTRY                       */
/****************************************************************/

AddBannedEntry: PROCEDURE expose (Globals)

    /* Prerequisite: none */

    PARSE ARG newentry tni

    Nul = D2C(0)
    IF tni THEN INIFile = 'WEASEL.TNI'
    ELSE INIFile = 'WEASEL.INI'

    /* Read the existing list of banned domains. */

    list = SysIni(INIFile, '$SYS', 'Banned')
    IF list = 'ERROR:' THEN list = ''

    /* Add the new entry to the list. */

    IF list = '' THEN list = newentry||Nul||Nul
    ELSE list = newentry||Nul||list
    CALL SysIni INIFile, '$SYS', 'Banned', list
    RETURN

/****************************************************************/

